@@ -10,7 +10,7 @@ from typing import Generic
 from typing import Sequence
 from typing import TypeVar
 
-from .base import Phantom
+from . import Phantom
 from .predicates import boolean
 from .predicates.generic import of_type
 
@@ -21,7 +21,9 @@ T = TypeVar("T")
 
 class SequenceNotStr(
     Sequence[T],
-    Phantom,
+    # Explicitly pass object here as workaround for this issue:
+    # https://github.com/python/cpython/issues/94607
+    Phantom[object],
     Generic[T],
     # Note: We don't eliminate mutable types here like in PhantomSized. This is because
     # the property of not being a str cannot change by mutation, so this specific
